@@ -8,16 +8,19 @@ class EpisodeManager(object):
     """Returns public episodes that are currently activated."""
 
     def itunespublished(self):
-        return self.get_query_set().exclude(Q(publised=None) | Q(block=True))
+        return self.get_query_set().exclude(Q(published=None) | Q(block=True))
 
     def published(self):
         return self.exclude(published=None)
 
-    def current(self):
-        return self.published().order_by("-published")
-
     def onsite(self):
-        return self.filter(site=Site.objects.get_current())
+        return self.filter(show__site=Site.objects.get_current())
+
+    def current(self):
+        try:
+            return self.published().order_by("-published")[0]
+        except IndexError:
+            return None
 
 
 class ShowManager(object):
